{% extends 'proctored_exam/rejected.html' %}
{% load i18n %}

{% block title %}
  {% blocktrans %}
    Your onboarding session was reviewed, but did not pass all requirements
  {% endblocktrans %}
{% endblock %}

{% block body %}
  <p>
    {% blocktrans %}
      Please contact
      <a href="mailto:{{ integration_specific_email }}">
        {{ integration_specific_email }}
      </a> if you have questions, or to retry your onboarding exam.
    {% endblocktrans %}
  </p>
{% endblock %}

{% block footer_content %}
{% endblock %}
